"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestSuite = void 0;
const test_block_1 = require("./test-block");
function arrayify(d) {
    if (!d)
        return [];
    return Array.isArray(d) ? d : [d];
}
class TestSuite {
    constructor(api, props) {
        this.api = api;
        this.props = props;
        const tests = Array.isArray(props.tests)
            ? props.tests
            : Object.entries(props.tests)
                .map(([testName, def]) => ({
                ...def,
                name: testName
            }));
        this.tests = tests.map((def) => ('test' in def)
            ? new test_block_1.TestBlock(api, def)
            : new TestSuite(api, def));
        this.hooks = {
            before: arrayify(props.before),
            beforeEach: arrayify(props.beforeEach),
            after: arrayify(props.after),
            afterEach: arrayify(props.afterEach)
        };
    }
    getProps() {
        return this.props;
    }
    run(context) {
        // tslint:disable-next-line:no-this-assignment
        const { api, props, tests, hooks } = this;
        api.describe(props, () => {
            Object.entries(hooks)
                .forEach(([hookName, hookFnList]) => hookFnList
                .forEach((hook) => api[hookName](hook.bind(context))));
            tests.forEach(test => test.run(context));
        });
    }
}
exports.TestSuite = TestSuite;
//# sourceMappingURL=test-suite.js.map